/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 * 
 */
package net.sf.genomeview.core;

import java.util.HashMap;

/**
 * 
 * @author Thomas Abeel
 * 
 * @param <T>
 *            forward key, reverse value type
 * @param <X>
 *            reverse key, forward value type
 */
public class BiMap<T, X> {
	private HashMap<T, X> forward = new HashMap<T, X>();
	private HashMap<X, T> reverse = new HashMap<X, T>();

	public X getForward(T key) {
		return forward.get(key);
	}

	public T getReverse(X key) {
		return reverse.get(key);
	}

	public int size() {
		return forward.size();
	}

	public void clear() {
		forward.clear();
		reverse.clear();
	}

	public void putForward(T e, X i) {
		forward.remove(e);
		reverse.remove(i);
		forward.put(e, i);
		reverse.put(i, e);

	}

	public void putReverse(X i, T e) {
		putForward(e, i);

	}

	public boolean containsForward(String key) {
		return forward.containsKey(key);
	}

}